"""
These are manual tests for the jetracerros2 package. 
They test speed, collision detection and turning. Therefore, the tests can not be automated.
Running these tests with pytest will not detect any errors.
"""

import time
import math

from uppaal2jetracer.jetracerros2.jetracerros2.turn_controller import TurnController
from uppaal2jetracer.jetracerros2.jetracerros2.speed_controller import SpeedController
from uppaal2jetracer.jetracerros2.jetracerros2.collision_controller import CollisionController

def manual_test_speed():
    """
    Test the speed of the JetRacer.
    Measure the distance the JetRacer travels in 1 second to determine the speed.
    """
    speed_controller = SpeedController()
    speed_controller.set_speed(1.0)
    time.sleep(1)
    speed_controller.set_speed(0.0)

def manual_test_collision_detection():
    """
    Test the collision detection of the JetRacer.
    If collision_threshold is not set, it defaults to 0.8 meters.
    """
    collision_controller = CollisionController()
    collision_threshold: float = None # in meters
    try:
        while True:
            print(f"""Collision detected:
                  {collision_controller.potential_collision(collision_threshold)}""")
    except KeyboardInterrupt:
        pass

def manual_test_turn():
    """
    Test the turning of the JetRacer.
    """

    theta: float = 90 # in degrees
    turn_controller = TurnController()
    turn_controller.turn(math.radians(theta))
